from sqlalchemy.orm import Session
from sqlalchemy import update

from models import BookCategoryStatistics, Book


def update_category_statistics(session: Session, book_id: int):
    book = session.query(Book).filter_by(id=book_id).first()

    if not book:
        raise ValueError(f"Book with ID {book_id} does not exist.")

    for category in book.categories:
        statistics = session.query(BookCategoryStatistics).filter_by(category_id=category.id).one_or_none()

        if statistics:
            statistics.book_count += 1
            session.add(statistics)
        else:
            new_statistics = BookCategoryStatistics(category_id=category.id, book_count=1)
            session.add(new_statistics)


__all__ = ["update_category_statistics"]
